@@ -1,40 +1,57 @@
 package POD2::ES;
-use warnings;
+
+use 5.005;
 use strict;
+use vars qw($VERSION);
+$VERSION = '5.12.3.01_1';
+
+use base qw(Exporter);
+our @EXPORT = qw(print_pod print_pods search_perlfunc_re new pod_dirs);
 
 use utf8;
-use base 'POD2::Base';
-
-our $VERSION = '5.12.3.01';
 
 my $pods = {
-    perlintro   => '5.12.3',
-    # perl       => '5.12.3',
-    # perlbook   => '5.12.3',
-    # perlcheat  => '5.12.3',
-    # perldata   => '5.12.3',
-    # perlfunc   => '5.12.3',
-    # perlstyle  => '5.12.3',
-    # perlsyn    => '5.12.3',
+    perlintro	=> '5.12.3',
+    # perl	=> '5.12.3',
+    # perlbook	=> '5.12.3',
+    # perlcheat => '5.12.3',
+    # perldata	=> '5.12.3',
+    # perlfunc	=> '5.12.3',
+    # perlstyle => '5.12.3',
+    # perlsyn	=> '5.12.3',
 };
 
+sub new {
+    return __PACKAGE__;
+}
+
+sub pod_dirs {
+    ( my $mod = __PACKAGE__ . '.pm' ) =~ s|::|/|g;
+    ( my $dir = $INC{$mod} ) =~ s/\.pm\z//;
+    return $dir;
+}
+
+sub print_pods {
+    print_pod(sort keys %$pods);
+}
 
 sub print_pod {
     my @args = @_ ? @_ : @ARGV;
 
     while (@args) {
-        (my $pod = lc(shift @args)) =~ s/\.pod$//;
-        if ( exists $pods->{$pod} ) {
-            print "\t'$pod' traducido correspondiente a Perl $pods->{$pod}\n";
-        } else {
-            print "\t'$pod' no existe\n";
-        }
+	(my $pod = lc(shift @args)) =~ s/\.pod$//;
+	if ( exists $pods->{$pod} ) {
+	    print "\t'$pod' traducido correspondiente a Perl
+$pods->{$pod}\n";
+	}
+	else {
+	    print "\t'$pod' todava no existe\n";
+	}
     }
 }
 
-
 sub search_perlfunc_re {
-    return 'Lista de funciones de Perl en orden alfabtico';
+    return 'Listado alfabtico de funciones de Perl';
 }
 
 1;
@@ -42,7 +59,8 @@ __END__
 
 =head1 NOMBRE
 
-POD2::ES - Documentacin de Perl en espaol
+POD2::ES - Documentacin de Perl en espaol / Spanish translation of Perl
+core documentation
 
 =head1 SINOPSIS
 
@@ -58,16 +76,17 @@ POD2::ES - Documentacin de Perl en espaol
 =head1 DESCRIPCIN
 
 pod2es es el proyecto de traduccin al espaol de la documentacin bsica
-de Perl. Por su dimensin, es un proyecto a largo plazo.   
+de Perl. Por su dimensin, es un proyecto a largo plazo. :-) 
 
-Vea L<http://github.com/zipf/perldoc-es> para obtener ms informacin. 
+Consulte L<http://github.com/zipf/perldoc-es> para obtener ms informacin
+sobre el proyecto. 
 
 Cuando haya instalado el paquete, puede utilizar el siguiente comando para
 consultar la documentacin: 
 
   %> perldoc POD2::ES::<nombre_de_pod>
 
-=head1 ACTUALIZACIN DE perldoc
+=head1 EXTENSIN DE perldoc
 
 Por desgracia, los tiles modificadores C<-f> y C<-q> de C<perldoc> no
 funcionan con la documentacin traducida.
@@ -93,7 +112,8 @@ para no tener que escribir el modificador C<-L> cada vez:
  
 Puede aplicar la revisin con la lnea siguiente: 
 
-  %> patch -p0 `/ruta_de_perl -MPod::Perldoc -e 'print $INC{"Pod/Perldoc.pm"}'` < /ruta/Perldoc.pm-3.14-patch
+  %> patch -p0 `/ruta_de_perl -MPod::Perldoc -e 'print
+$INC{"Pod/Perldoc.pm"}'` < /ruta/Perldoc.pm-3.14-patch
 
 La revisin se incluye con esta distribucin y se encuentra en
 F<./patches/Perldoc.pm-3.14-patch>.
@@ -103,7 +123,7 @@ L<Pod::Perldoc|Pod::Perldoc>
 (incluida en Perl 5.8.7 y en Perl 5.8.8). Si tiene una distribucin de Perl
 anterior
 (salvo la E<gt>= 5.8.1) y est impaciente por aplicar la revisin,
-actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la versin 3.14.   
+actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la versin 3.14. ;-) 
 
 Consulte la API C<search_perlfunc_re> para obtener ms informacin.
 
@@ -141,10 +161,10 @@ pods pasados como argumentos.
 =item * C<search_perlfunc_re>
 
 Como el mtodo C<search_perlfunc> de F<Pod/Perldoc.pm> utiliza la cadena
-"Lista de funciones de Perl en orden alfabtico" incluida en el cdigo
-(como una expresin regular) para omitir la introduccin, a fin de que el
-archivo de revisin funcione con otros idiomas con la opcin C<-L>, hemos
-utilizado un mecanismo sencillo, similar a un complemento. 
+"Lista alfabtica de funciones de Perl" incluida en el cdigo (como una
+expresin regular) para omitir la introduccin, a fin de que el archivo de
+revisin funcione con otros idiomas con la opcin C<-L>, hemos utilizado un
+mecanismo sencillo, similar a un complemento. 
 
 El paquete de idioma C<POD2::E<lt>idiomaE<gt>> debe exportar
 C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada
@@ -157,63 +177,14 @@ aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
 
 =back
 
-=head1 PROYECTO
+=head1 Ms informacin sobre el proyecto
 
-Encontrar ms informacin sobre el proyecto en
-L<http://github.com/zipf/perldoc-es>.
+Visite L<http://github.com/zipf/perldoc-es> para obtener ms informacin.
 
 =head1 AUTORES
 
-=over
-
-=item * Joaqun Ferrero, C< explorer at joaquinferrero.com >
-
-=item * Enrique Nell, C< blas.gordon at gmail.com >
-
-=back
-
-=head1 NOTAS SOBRE LA TRADUCCIN
-
-Para este proyecto hemos tomado las siguientes decisiones:
-
-=over
-
-=item * No utilizar caracteres acentuados en los nombres de variables y
-funciones de los ejemplos de cdigo
-
-Es perfectamente posible utilizarlos (solo hay que codificar el programa
-como UTF-8 y agregar "use utf8;" al principio), pero teniendo en mente a
-ese programador ms impulsivo, que valora su tiempo y no quiere perderse en
-reflexiones ni verse encorsetado por las normas de la lengua, creemos que
-as resultar ms fcil probar el cdigo de los ejemplos.
-
-Por otra parte, en aquellos sistemas que cuenten con un sistema antiguo de
-visualizacin de texto, como los terminales de lnea de comandos, es posible
-que se pierdan los acentos. En la mayor parte de los casos ser debido
-a la presencia de una versin de groff (programa utilizado por los comandos
-man y perldoc) que no admite dichos caracteres. En la documentacin
-HTML no debera haber problemas.
-
-
-=item * No traducir los trminos "array" y "hash"
-
-Si tenemos en cuenta que Perl tiene ms de 20 aos y que la inmensa mayora
-de los libros disponibles sobre este lenguaje estn en ingls, a nadie extraar
-que la comunidad de habla hispana se refiera a estos tipos de datos por su
-nombre en ingls. Existen posibles traducciones, como "matriz", "lista" o
-"arreglo" para "array", o "diccionario" para "hash", pero su uso no se ha
-extendido, por lo que hemos preferido utilizar su nombre original.
-Creemos que esto facilitar la lectura de la documentacin.
-
-
-=item * Utilizar "espaol neutro"
-
-El "espaol neutro" es un espaol controlado que pretende evitar el uso de
-trminos ofensivos o de construcciones poco frecuentes en determinados pases
-de habla hispana, con el objetivo de lograr traducciones vlidas para 
-Espaa y Latinoamrica.
-
-=back
+Joaqun Ferrero C<< explorer at joaquinferrero.com >>
+y Enrique Nell C<< blas.gordon at gmail.com >>.
 
 
 =head1 VEA TAMBIN
@@ -224,9 +195,9 @@ L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>, L<perl>.
 =head1 ERRORES
 
 Puede notificar errores (bugs) o solicitar funcionalidad a travs de la
-direccin de correo electrnico C<bug-pod2-esd at rt.cpan.org> o de la
-interfaz web en L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>. 
-Se le comunicarn automticamente los cambios relacionados con los errores
+direccin C<bug-pod2-esd at rt.cpan.org> o de la interfaz web en
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>.  Se le
+comunicarn automticamente los cambios relacionados con los errores
 notificados o la funcionalidad solicitada.
 
 
@@ -262,26 +233,6 @@ L<http://search.cpan.org/dist/POD2-ES/>
 
 =head1 AGRADECIMIENTOS
 
-Los autores desean expresar su gratitud al equipo de desarrollo
-de OmegaT, la herramienta utilizada para la traduccin.
-
-
-=head1 REFERENCIAS
-
-Proyecto OmegaT: L<http://omegat.org/>
-
-
-=head1 DONATIVOS
-
-Por el elevado volumen de trabajo que representa y su larga duracin,
-el proyecto de traduccin de la documentacin de Perl requiere un 
-esfuerzo sostenido que slo est al alcance de los espritus ms 
-slidos y altruistas.
-Los autores no exigen, pero tampoco rechazarn, compensaciones en 
-forma de dinero, libros, quesos y productos derivados del cerdo (o chancho),
-o incluso viajes a la Polinesia, destinadas a reducir la fatiga del
-equipo y a mantener alta la moral. Todo ser bienvenido.
-
 
 =head1 LICENCIA Y COPYRIGHT
 
@@ -291,7 +242,14 @@ Este programa es software libre; puede redistribuirlo o modificarlo bajo
 los trminos de la licencia GNU General Public License publicada por la
 Free Software Foundation, o los de la licencia Artistic.
 
-Consulte http://dev.perl.org/licenses/ para obtener ms informacin.
+	Consulte http://dev.perl.org/licenses/ para obtener ms
+informacin.
 
 
 =cut
+
+
+=head1 TRADUCTORES
+
+Joaqun Ferrero C<< explorer at joaquinferrero.com >>
+Enrique Nell C<< blas.gordon at gmail.com >>
